% Reading and visualising 3D reconstruction errors reported in our CVPR 2013 paper 

% Author: Ravi Garg

% Cite our CVPR 2013 while using the data for 3D reconstruction
% ' Dense Variational Reconstruction of Non-Rigid Surfaces from Monocular Video '
%  Ravi Garg, Anastasios Roussos, Lourdes Agapito
%  IEEE Conference on Computer Vision and Pattern Recognition (CVPR) 2013.

%  Please send bug reports and queries to : l dot agapito at cs dot ucl dot ac dot uk



% NOTE: Please note that this code has been modified to facilitate accurate
% RMS and Mean RMS error estimation. Thus the results reported in Garg etal
% differs from the one this script produces. We advice the users to report 
% the new error scores generated by this script for all the methods.

% However, we have incorporated the version to compute the
% error measures which were reported in Garg etal CVPR 2013.

% If the user choose to reproduce error measures reported in CVPR 2013,
% s/he can do so by changing the value of variable ' flag_error_type ' to ‘ 1 ’.



%% Set Important flags here
% flag_error_type: Default value 2
% Use 1 for replicating results reported in Garg etal CVPR.
% Use 2 for correctly estimating rms and average rms errors.
flag_error_type = 2; 

% list_methods: Default value {'TB','MP','ours','oursMod'};
% List of methods to compute error scores for:
list_methods = {'TB','MP','ours'};

%  baseline_method_index: Default value 3
%  Used to plot the avg. rms. error ratios w.r.t. a given method
%  Use empty array ( [] ) for plotting absolute error measures
%  By default we plot the errors w.r.t Garg etal CVPR 2013 i.e. index 3 in
%  the list_methods
baseline_method_index = 3;



%% Compute error scores
for i = 1:4 % for all the sequence
    path_seq = sprintf('Seq%d',i);
    path_GT = fullfile(path_seq,'GT.mat')
    for j = 1:length(list_methods); % for all the mothods in the list
        path_result = fullfile(path_seq,[list_methods{j} '.mat']);
        e_current = compute_error(path_GT,path_result,flag_error_type);
        e_rms(i,j) = e_current.rms;
        e_mean_rms(i,j) = e_current.mean_rms;
    end
end

%% Visualise
if ~isempty(baseline_method_index)
    figure, bar(e_mean_rms./repmat(min(e_mean_rms')',1,length(list_methods)),'grouped');
    legend(deal(list_methods)); title('relative mean rms errors');
    figure, bar(e_rms./repmat(min(e_rms')',1,length(list_methods)),'grouped');
    legend(deal(list_methods)); title('relative rms errors');
else
    figure, bar(e_mean_rms,'grouped');
    legend(deal(list_methods)); title('mean rms errors');
    figure, bar(e_rms,'grouped');
    legend(deal(list_methods)); title('rms errors');
end
